@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our @ISA = qw(Tie::StdHash);
 use Carp 'croak';
@@ -30,7 +30,7 @@ sub _parse_usage {
         require File::Which;
 	$DU_BIN = File::Which::which('du');
     }
-    open PIPE, "$DU_BIN @_ $path |" or exit 1;       
+    open PIPE, "$DU_BIN @_ $path & |" or exit 1;       
     my %usage;
     for (<PIPE>) {
         my($size, $item) = split;
@@ -59,14 +59,14 @@ Tie::DiskUsage - tie disk-usage to an hash.
 
 =head1 DESCRIPTION
 
-C<Tie::DiskUsage> ties the disk-usage, which is gathered
+Tie::DiskUsage ties the disk-usage, which is gathered
 from the output of C<du>, to an hash. The mandatory parameter 
 consists of the path to perform the du-command on e.g. F</etc>, 
 optional arguments to C<du> may be passed subsequently.
 
 By default the location of the du-command is to be
 assumed in F</usr/bin/du>; if C<du> cannot be found there, 
-C<File::Which> will attempt to gather its proper location.
+C<File::Which> will attempt to gather its former location.
 
 =head1 SEE ALSO
 
